# idmaths

A collection of useful modules to generate mathematical constants and sequences missing from the general Python distribution.


### Prerequisites



```
numpy
sympy
decimal
```

### Installing

```
pip install idmaths
```

## Author

* **Ivan Debono [ivandebono](https://github.com/ivandebono)



## License

This project is licensed under the MIT License - see the [LICENCE.md](LICENCE.md) file for details

